----------------------------------------------------------------------------
--  cnt5.vhd
--	7Series 5bit Fast Counter
--	Version 1.0
--
--  Copyright (C) 2019 H.Poetzl
--
--	This program is free software: you can redistribute it and/or
--	modify it under the terms of the GNU General Public License
--	as published by the Free Software Foundation, either version
--	2 of the License, or (at your option) any later version.
--
--  Vivado 2018.3:
--    mkdir -p build.vivado
--    (cd build.vivado && vivado -mode tcl -source ../vivado.tcl)
----------------------------------------------------------------------------


library IEEE;
use IEEE.std_logic_1164.ALL;
use IEEE.numeric_std.ALL;

library unisim;
use unisim.VCOMPONENTS.ALL;


entity cnt5 is
    port (
	clk	: in std_logic;
	--
	reg	: out std_logic_vector (4 downto 0);
	link	: out std_logic
    );
end entity cnt5;


architecture LUT of cnt5 is

    signal lut_r : std_logic_vector (5 downto 0);
    signal lut_o : std_logic_vector (5 downto 0);

    attribute RLOC: string;
    attribute RLOC of LUT6_2_inst0 : label is "X0Y0";
    attribute RLOC of LUT6_2_inst1 : label is "X0Y0";
    attribute RLOC of LUT6_2_inst2 : label is "X0Y0";

begin

    LUT6_2_inst0 : LUT6_2
    generic map (
	INIT => b"01100110011001100110011001100110_01010101010101010101010101010101")
    port map (
	O5 => lut_o(0),
	O6 => lut_o(1),
	I0 => lut_r(0),
	I1 => lut_r(1),
	I2 => lut_r(2),
	I3 => lut_r(3),
	I4 => lut_r(4),
	I5 => '1');

    LUT6_2_inst1 : LUT6_2
    generic map (
	INIT => b"01111111100000000111111110000000_01111000011110000111100001111000")
    port map (
	O5 => lut_o(2),
	O6 => lut_o(3),
	I0 => lut_r(0),
	I1 => lut_r(1),
	I2 => lut_r(2),
	I3 => lut_r(3),
	I4 => lut_r(4),
	I5 => '1');

    LUT6_2_inst2 : LUT6_2
    generic map (
	INIT => b"01000000000000000000000000000000_01111111111111111000000000000000")
    port map (
	O5 => lut_o(4),
	O6 => lut_o(5),
	I0 => lut_r(0),
	I1 => lut_r(1),
	I2 => lut_r(2),
	I3 => lut_r(3),
	I4 => lut_r(4),
	I5 => '1');

    GEN_REG : for N in 0 to 5 generate
	attribute RLOC of FDPE_inst : label is "X0Y0";
    begin
	FDPE_inst : FDPE
	generic map (
	    INIT => '1')
	port map (
	    Q => lut_r(N),
	    D => lut_o(N),
	    C => clk,
	    CE => '1', 
	    PRE => '0');
    end generate;

    reg <= lut_r(4 downto 0);
    link <= lut_r(5);

end architecture;

