# vivado.tcl
#	TE0714 simple example
#	Version 1.0
# 
# Copyright (C) 2017 H.Poetzl

set ODIR .

# STEP#1: setup design sources and constraints

read_vhdl -vhdl2008 ../cnt5.vhd
read_xdc ../top.xdc

set_property PART xc7a50tcsg325-2 [current_project]
set_property TARGET_LANGUAGE VHDL [current_project]

# STEP#2: run synthesis, write checkpoint design

synth_design -top cnt5 -flatten rebuilt    
write_checkpoint -force $ODIR/post_synth

# STEP#3: run placement and logic optimzation, write checkpoint design

opt_design -propconst -sweep -retarget -remap

place_design -directive Quick
phys_opt_design -critical_cell_opt -critical_pin_opt -placement_opt -hold_fix -rewire -retime
power_opt_design
write_checkpoint -force $ODIR/post_place

# STEP#4: run router, write checkpoint design

route_design -directive Quick
write_checkpoint -force $ODIR/post_route

report_timing -no_header -path_type summary -max_paths 1000 -slack_lesser_than 0 -setup
report_timing -no_header -path_type summary -max_paths 1000 -slack_lesser_than 0 -hold

# STEP#6: generate reports

report_clocks

report_utilization -hierarchical -file utilization.rpt
report_clock_utilization -file utilization.rpt -append
report_datasheet -file datasheet.rpt
report_timing_summary -file timing.rpt
report_drc -file drc.rpt

puts "MESSAGE: all done"
